summaryrefslogtreecommitdiffstats
path: root/kppp/opener.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kppp/opener.cpp')
-rw-r--r--kppp/opener.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kppp/opener.cpp b/kppp/opener.cpp
index 7f61f775..88d27c87 100644
--- a/kppp/opener.cpp
+++ b/kppp/opener.cpp
@@ -30,7 +30,7 @@
* the setuid root part of kppp. So please be careful !
* o restrain from using X, TQt or KDE library calls
* o check for possible buffer overflows
* o handle requests from the tqparent process with care. They might be forged.
* o be paranoid and think twice about everything you change.
*/
@@ -519,7 +519,7 @@ bool Opener::execpppd(const char *arguments) {
switch(pppdPid = fork())
{
case -1:
- fprintf(stderr,"In tqparent: fork() failed\n");
+ fprintf(stderr,"In parent: fork() failed\n");
return false;
break;
@@ -561,7 +561,7 @@ bool Opener::execpppd(const char *arguments) {
break;
default:
- Debug2("In tqparent: pppd pid %d\n",pppdPid);
+ Debug2("In parent: pppd pid %d\n",pppdPid);
close(ttyfd);
ttyfd = -1;
return true;
@@ -30,7 +30,7 @@
* o restrain from using X, TQt or KDE library calls
* o check for possible buffer overflows
- * o handle requests from the tqparent process with care. They might be forged.
+ * o handle requests from the parent process with care. They might be forged.
* o be paranoid and think twice about everything you change.
*/